@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::MinimumVersionTests;
 # ABSTRACT: Release tests for minimum required versions
-our $VERSION = '2.000006'; # VERSION
+our $VERSION = '2.000007'; # VERSION
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::MinimumVersion';
 
@@ -29,7 +29,9 @@ Dist::Zilla::Plugin::MinimumVersionTests - Release tests for minimum required ve
 
 =head1 VERSION
 
-version 2.000006
+version 2.000007
+
+=for test_synopsis BEGIN { die "SKIP: Synopsis isn't Perl code" }
 
 =head1 SYNOPSIS
 
@@ -37,9 +39,6 @@ In C<dist.ini>:
 
     [Test::MinimumVersion]
 
-=for test_synopsis 1;
-__END__
-
 =head1 AVAILABILITY
 
 The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-Test-MinimumVersion/>.
